MapFilterArrayMatcherAnyMatcher class

Inheritance

Constructors

MapFilterArrayMatcherAnyMatcher(String field, MapMatcher matcher)

Properties

field → String
final
hashCode → int
The hash code for this object.
no setterinherited
matcher → MapMatcher
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(Map map) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited