MapSorting class

Constructors

MapSorting()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(SortExpr? expr) → MapComparator
sort(List<Map<String, dynamic>> items, SortExpr sort) → List<Map<String, dynamic>>
traverse(Map map, String key) → ({bool exists, dynamic value})