query_dsl library

Functions

and(List<FilterExpr> filters) → FilterExpr
Matches if all of the given filters match.
arrayContains(String field, dynamic value) → FilterExpr
Matches if the field contains exactly the given value.
eq<STRUCT>(String field, dynamic value) → FilterExpr
Matches if the field is equal to the given value. If STRUCT is specified, the value is expected to be a STRUCT instance and is automatically converted to a Map.
exists(String field, {bool value = true}) → FilterExpr
Matches if the field's existence matches the given value.
gt(String field, dynamic value) → FilterExpr
Matches if the field is greater than the given value.
gte(String field, dynamic value) → FilterExpr
Matches if the field is greater than or equal to the given value.
inArray(String field, List values) → FilterExpr
Matches if the field contains any of the given values.
lt(String field, dynamic value) → FilterExpr
Matches if the field is less than the given value.
lte(String field, dynamic value) → FilterExpr
Matches if the field is less than or equal to the given value.
nativeFilter(Object obj) → FilterExpr
ne<STRUCT>(String field, dynamic value) → FilterExpr
Matches if the field is not equal to the given value. If STRUCT is specified, the value is expected to be a STRUCT instance and is automatically converted to a Map.
notInArray(String field, List values) → FilterExpr
Matches if the field does not contain any of the given values.
or(List<FilterExpr> filters) → FilterExpr
Matches if any of the given filters match.