eq<STRUCT> function
Matches if the field is equal to the given value.
If STRUCT is specified, the value is expected to be a STRUCT instance
and is automatically converted to a Map.
Implementation
FilterExpr eq<STRUCT>(String field, dynamic value) {
if (STRUCT == dynamic) return FilterEq(field, value);
return FilterEqStruct<STRUCT>(field, value);
}